@@ -1,6 +1,6 @@
-var _isArray = require('./_isArray');
-var _isTransformer = require('./_isTransformer');
+var _isArray = /*#__PURE__*/require('./_isArray');
 
+var _isTransformer = /*#__PURE__*/require('./_isTransformer');
 
 /**
  * Returns a function that dispatches with different strategies based on the
@@ -16,8 +16,10 @@ var _isTransformer = require('./_isTransformer');
  * @param {Function} fn default ramda implementation
  * @return {Function} A function that dispatches on object in list position
  */
-module.exports = function _dispatchable(methodNames, xf, fn) {
-  return function() {
+
+
+function _dispatchable(methodNames, xf, fn) {
+  return function () {
     if (arguments.length === 0) {
       return fn();
     }
@@ -38,4 +40,5 @@ module.exports = function _dispatchable(methodNames, xf, fn) {
     }
     return fn.apply(this, arguments);
   };
-};
+}
+module.exports = _dispatchable;
\ No newline at end of file
